@@ -22,10 +22,10 @@ score_fct = function(y, d, g0_hat, g1_hat, m_hat, smpls) {
 on_cran = !identical(Sys.getenv("NOT_CRAN"), "true")
 if (on_cran) {
   test_cases = expand.grid(
-    learner = "regr.glmnet",
-    learner_m = "classif.glmnet",
+    learner = "regr.rpart",
+    learner_m = "classif.rpart",
     dml_procedure = "dml2",
-    trimming_threshold = 0,
+    trimming_threshold = 1e-5,
     stringsAsFactors = FALSE)
   test_cases[".test_name"] = apply(test_cases, 1, paste, collapse = "_")
 } else {
@@ -33,7 +33,7 @@ if (on_cran) {
     learner = "regr.glmnet",
     learner_m = "classif.glmnet",
     dml_procedure = c("dml1", "dml2"),
-    trimming_threshold = c(0, 0.01),
+    trimming_threshold = c(1e-5, 0.01),
     stringsAsFactors = FALSE)
   test_cases[".test_name"] = apply(test_cases, 1, paste, collapse = "_")
 }
